@@ -6,7 +6,7 @@
 # Set up a button to have an animated loading indicator and a checkmark
 # for better user experience
 # Need to use with the corresponding `withBusyIndicator` server function
-withBusyIndicatorUI <- function(button) {
+withBusyIndicatorUI = function(button) {
   id=button[['attribs']][['id']]
   if(is.null(id))
   {
@@ -44,11 +44,11 @@ withBusyIndicatorUI <- function(button) {
 
 # Call this function from the server with the button id that is clicked and the
 # expression to run when the button is clicked
-withBusyIndicatorServer <- function(buttonId, expr) {
+withBusyIndicatorServer = function(buttonId, expr) {
   # UX stuff: show the "busy" message, hide the other messages, disable the button
-  loadingEl <- sprintf("[data-for-btn=%s] .btn-loading-indicator", buttonId)
-  doneEl <- sprintf("[data-for-btn=%s] .btn-done-indicator", buttonId)
-  errEl <- sprintf("[data-for-btn=%s] .btn-err", buttonId)
+  loadingEl = sprintf("[data-for-btn=%s] .btn-loading-indicator", buttonId)
+  doneEl = sprintf("[data-for-btn=%s] .btn-done-indicator", buttonId)
+  errEl = sprintf("[data-for-btn=%s] .btn-err", buttonId)
   shinyjs::disable(buttonId)
   shinyjs::show(selector = loadingEl)
   shinyjs::hide(selector = doneEl)
@@ -60,8 +60,9 @@ withBusyIndicatorServer <- function(buttonId, expr) {
   
   # Try to run the code when the button is clicked and show an error message if
   # an error occurs or a success message if it completes
+  #tryCatchLog
   tryCatch({
-    value <- expr
+    value = expr
     shinyjs::show(selector = doneEl)
     shinyjs::delay(2000, shinyjs::hide(selector = doneEl, anim = TRUE, animType = "fade",
                                        time = 0.5))
@@ -70,10 +71,10 @@ withBusyIndicatorServer <- function(buttonId, expr) {
 }
 
 # When an error happens after a button click, show the error
-errorFunc <- function(err, buttonId) {
-  errEl <- sprintf("[data-for-btn=%s] .btn-err", buttonId)
-  errElMsg <- sprintf("[data-for-btn=%s] .btn-err-msg", buttonId)
-  errMessage <- gsub("^ddpcr: (.*)", "\\1", err$message)
+errorFunc = function(err, buttonId) {
+  errEl = sprintf("[data-for-btn=%s] .btn-err", buttonId)
+  errElMsg = sprintf("[data-for-btn=%s] .btn-err-msg", buttonId)
+  errMessage = gsub("^ddpcr: (.*)", "\\1", err$message)
   shinyjs::html(html = errMessage, selector = errElMsg)
   shinyjs::show(selector = errEl, anim = TRUE, animType = "fade")
 }
\ No newline at end of file
